@@ -161,7 +161,7 @@ get '/remove' => sub ($c) {
   }
 } => 'remove';
 
-get '/edit' => sub ($c) {
+get '/edit_setting' => sub ($c) {
   my $id         = $c->param('id');
   my $name       = $c->param('name');
   my $model      = $c->param('model');
@@ -198,14 +198,14 @@ get '/edit' => sub ($c) {
     is_default => $is_default,
   };
   $c->render(
-    template => 'edit',
+    template => 'edit_setting',
     specs    => $specs,
     id       => $id,
     name     => $name,
     model    => $model,
     selected => $selected,
   );
-} => 'edit';
+} => 'edit_setting';
 
 post '/update' => sub ($c) {
   my $v = $c->validation;
@@ -224,7 +224,7 @@ post '/update' => sub ($c) {
   $v->optional('id');
   if ($v->failed->@*) {
     $c->flash(error => 'Could not update');
-    return $c->redirect_to('edit');
+    return $c->redirect_to('edit_setting');
   }
   my $model = trim $v->param('model') if $v->param('model');
   my $name  = trim $v->param('name')  if $v->param('name');
@@ -248,7 +248,7 @@ post '/update' => sub ($c) {
     is_default => $v->param('is_default'),
   );
   $c->flash(message => 'Update setting successful');
-  $c->redirect_to($c->url_for('edit')->query(
+  $c->redirect_to($c->url_for('edit_setting')->query(
     id         => $id,
     name       => $v->param('name'),
     model      => $v->param('model'),
@@ -269,6 +269,25 @@ helper to_json => sub ($c, $data) {
   return to_json $data;
 };
 
+helper build_edit_url => sub ($c, $model, $id, $set) {
+  my $edit_url = $c->url_for('edit_setting')->query(
+    model      => $model,
+    $id ? (id => $id) : (),
+    name       => $set->{name},
+    group      => $set->{group},
+    parameter  => $set->{parameter},
+    control    => $set->{control},
+    group_to   => $set->{group_to},
+    param_to   => $set->{param_to},
+    bottom     => $set->{bottom},
+    top        => $set->{top},
+    value      => $set->{value},
+    unit       => $set->{unit},
+    is_default => $set->{is_default},
+  );
+  return $edit_url;
+};
+
 app->secrets(['yabbadabbadoo']);
 
 app->start;
@@ -316,7 +335,7 @@ __DATA__
   <div class="col">
     <button type="submit" id="search" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
 % if ($model) {
-    <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $group) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
+    <a href="<%= url_for('edit_setting')->query(model => $model, name => $name, group => $group) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
 % }
     <a href="<%= url_for('model') %>" class="btn btn-success" id="new_model"><i class="fa-solid fa-database"></i> New model</a>
 % if ($model) {
@@ -328,24 +347,13 @@ __DATA__
 </div>
 </form>
 <p></p>
+<ol>
 % for my $s (@$settings) {
 %   my $id = (keys(%$s))[0];
 %   my $setting = (values(%$s))[0];
-%   my $edit_url = url_for('edit')->query(
-%     model      => $model,
-%     id         => $id,
-%     name       => $setting->{name},
-%     group      => $setting->{group},
-%     parameter  => $setting->{parameter},
-%     control    => $setting->{control},
-%     group_to   => $setting->{group_to},
-%     param_to   => $setting->{param_to},
-%     bottom     => $setting->{bottom},
-%     top        => $setting->{top},
-%     value      => $setting->{value},
-%     unit       => $setting->{unit},
-%     is_default => $setting->{is_default},
-%   );
+%   my $edit_url = build_edit_url($model, $id, $setting);
+<li>
+&nbsp;
 <a href="<%= $edit_url %>" class="btn btn-sm btn-outline-secondary"><i class="fa-solid fa-pencil"></i></a>
 &nbsp;
 <b>Name</b>: <%= $setting->{name} %> ,
@@ -358,8 +366,9 @@ __DATA__
 ,
 <b>Value</b>: <%= $setting->{value} %> <%= $setting->{unit} %>
 %   }
-<br>
+</li>
 % }
+</ol>
 
 
 @@ model.html.ep
@@ -428,14 +437,14 @@ __DATA__
 % }
   <div class="row">
     <div class="col">
-      <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Update model</button>
+      <button type="submit" class="btn btn-primary"><i class="fa-solid fa-arrow-rotate-right"></i> Update model</button>
       <a href="<%= url_for('index')->query(model => $model) %>" id="cancel" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
     </div>
   </div>
 </form>
 
 
-@@ edit.html.ep
+@@ edit_setting.html.ep
 % layout 'default';
 <p></p>
 <form action="<%= url_for('update') %>" method="post">
@@ -497,7 +506,9 @@ __DATA__
 % if ($id) {
   <button type="submit" class="btn btn-primary"><i class="fa-solid fa-arrow-rotate-right"></i> Update</button>
   <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" id="remove" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove</a>
-  <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $selected->{group}) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
+% my $edit_url = build_edit_url($model, '', { name => $name, %$selected });
+  <a href="<%= $edit_url %>" id="clone_setting" class="btn btn-success"><i class="fa-solid fa-copy"></i> Clone</a>
+  <a href="<%= url_for('edit_setting')->query(model => $model, name => $name, group => $selected->{group}) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New</a>
 % } else {
   <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Submit</button>
 % }
