@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0033';
+our $VERSION = '0.0034';
 
 use Moo;
 use strictures 2;
@@ -115,20 +115,20 @@ sub search_settings {
   push @where, "name = '$name'" if $name;
   for my $arg (keys %args) {
     next unless $args{$arg};
-    $args{$arg} =~ s/'/''/g;
+    $args{$arg} =~ s/'/''/g; # escape the single-quote
     push @where, q/json_extract(settings, '$./ . $arg . q/') = / . "'$args{$arg}'";
   }
   return [] unless @where;
-  my $sql = q/select id,name,settings,json_extract(settings, '$.group') as mygroup from /
+  my $sql = q/select id,name,settings,json_extract(settings, '$.group') as mygroup, json_extract(settings, '$.parameter') as parameter from /
     . $self->model
     . ' where ' . join(' and ', @where)
-    . ' order by mygroup';
-  print "SQL: $sql\n" if $self->verbose;
+    . ' order by mygroup,parameter';
+  print "Search SQL: $sql\n" if $self->verbose;
   my $results = $self->_sqlite->query($sql);
   my @settings;
   while (my $next = $results->hash) {
     push @settings, { $next->{id} => from_json($next->{settings}) };
-    # add the setting name to the settings data
+    # add the setting name to the settings data so we can use it in the templates
     $settings[-1]->{ $next->{id} }{name} = $next->{name};
   }
   return \@settings;
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0033
+version 0.0034
 
 =head1 SYNOPSIS
 
